.. include:: ../README.rst

.. toctree::
   :maxdepth: 2

   installation
   usage
   development
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
* :ref:`glossary`
